summaryrefslogtreecommitdiff
path: root/build-aux
diff options
context:
space:
mode:
Diffstat (limited to 'build-aux')
-rw-r--r--build-aux/qmi-codegen/utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build-aux/qmi-codegen/utils.py b/build-aux/qmi-codegen/utils.py
index 55d4eae..1728a11 100644
--- a/build-aux/qmi-codegen/utils.py
+++ b/build-aux/qmi-codegen/utils.py
@@ -76,8 +76,8 @@ def add_header_start(f, output_name, service):
else:
template += (
"#include \"qmi-enums-private.h\"\n")
- # CTL, WDS, WMS, PDS, PBM and UIM don't have flags64
- if service != 'CTL' and service != 'WDS' and service != 'WMS' and service != 'PDS' and service != 'PBM' and service != 'UIM':
+ # CTL, WDS, WMS, PDS, PBM, UIM and OMA don't have flags64
+ if service != 'CTL' and service != 'WDS' and service != 'WMS' and service != 'PDS' and service != 'PBM' and service != 'UIM' and service != 'OMA':
template += (
"#include \"qmi-flags64-${service}.h\"\n")
template += (